@@ -1,6 +1,6 @@
 /*
    This file is part of GNUnet.
-   Copyright (C) 2021--2022 GNUnet e.V.
+   Copyright (C) 2021--2024 GNUnet e.V.
 
    GNUnet is free software: you can redistribute it and/or modify it
    under the terms of the GNU Affero General Public License as published
@@ -23,15 +23,25 @@
  */
 
 #include "gnunet_chat_util.h"
+#include <gnunet/gnunet_messenger_service.h>
+
+static const char label_prefix_of_contact [] = "contact";
+static const char label_prefix_of_group [] = "group";
 
 void
 util_shorthash_from_member (const struct GNUNET_MESSENGER_Contact *member,
-			    struct GNUNET_ShortHashCode *shorthash)
+			                      struct GNUNET_ShortHashCode *shorthash)
 {
   GNUNET_assert(shorthash);
 
+  const size_t id = GNUNET_MESSENGER_contact_get_id(member);
+
   memset(shorthash, 0, sizeof(*shorthash));
-  GNUNET_memcpy(shorthash, &member, sizeof(member));
+  GNUNET_memcpy(
+    shorthash,
+    &id,
+    sizeof(id) < sizeof(*shorthash) ? sizeof(id) : sizeof(*shorthash)
+  );
 }
 
 void
@@ -59,7 +69,7 @@ util_hash_file (const char *filename, struct GNUNET_HashCode *hash)
     return GNUNET_SYSERR;
 
   struct GNUNET_DISK_FileHandle *file = GNUNET_DISK_file_open(
-      filename, GNUNET_DISK_OPEN_READ, GNUNET_DISK_PERM_USER_READ
+    filename, GNUNET_DISK_OPEN_READ, GNUNET_DISK_PERM_USER_READ
   );
 
   if (!file)
@@ -71,7 +81,7 @@ util_hash_file (const char *filename, struct GNUNET_HashCode *hash)
   if (size > 0)
   {
     data = GNUNET_DISK_file_map(
-	file, &mapping, GNUNET_DISK_MAP_TYPE_READ, size
+	    file, &mapping, GNUNET_DISK_MAP_TYPE_READ, size
     );
 
     if ((!data) || (!mapping))
@@ -97,8 +107,8 @@ util_hash_file (const char *filename, struct GNUNET_HashCode *hash)
 
 int
 util_encrypt_file (const char *filename,
-		   const struct GNUNET_HashCode *hash,
-		   const struct GNUNET_CRYPTO_SymmetricSessionKey *key)
+                   const struct GNUNET_HashCode *hash,
+                   const struct GNUNET_CRYPTO_SymmetricSessionKey *key)
 {
   GNUNET_assert((filename) && (hash) && (key));
 
@@ -108,19 +118,19 @@ util_encrypt_file (const char *filename,
     return GNUNET_SYSERR;
 
   struct GNUNET_DISK_FileHandle *file = GNUNET_DISK_file_open(
-      filename, GNUNET_DISK_OPEN_READWRITE,
-      GNUNET_DISK_PERM_USER_READ | GNUNET_DISK_PERM_USER_WRITE
+    filename, GNUNET_DISK_OPEN_READWRITE,
+    GNUNET_DISK_PERM_USER_READ | GNUNET_DISK_PERM_USER_WRITE
   );
 
   if (!file)
     return GNUNET_SYSERR;
 
-  if (size <= 0)
+  if (!size)
     return GNUNET_DISK_file_close(file);
 
   struct GNUNET_DISK_MapHandle *mapping;
   const void* data = GNUNET_DISK_file_map(
-      file, &mapping, GNUNET_DISK_MAP_TYPE_READWRITE, size
+    file, &mapping, GNUNET_DISK_MAP_TYPE_READWRITE, size
   );
 
   if ((!data) || (!mapping))
@@ -160,7 +170,7 @@ util_encrypt_file (const char *filename,
       break;
   }
 
-  if ((mapping) && (GNUNET_OK != GNUNET_DISK_file_unmap(mapping)))
+  if (GNUNET_OK != GNUNET_DISK_file_unmap(mapping))
     result = -1;
 
   if (GNUNET_OK != GNUNET_DISK_file_sync(file))
@@ -177,8 +187,8 @@ util_encrypt_file (const char *filename,
 
 int
 util_decrypt_file (const char *filename,
-		   const struct GNUNET_HashCode *hash,
-		   const struct GNUNET_CRYPTO_SymmetricSessionKey *key)
+                   const struct GNUNET_HashCode *hash,
+                   const struct GNUNET_CRYPTO_SymmetricSessionKey *key)
 {
   GNUNET_assert((filename) && (hash) && (key));
 
@@ -188,8 +198,8 @@ util_decrypt_file (const char *filename,
     return GNUNET_SYSERR;
 
   struct GNUNET_DISK_FileHandle *file = GNUNET_DISK_file_open(
-      filename, GNUNET_DISK_OPEN_READWRITE,
-      GNUNET_DISK_PERM_USER_READ | GNUNET_DISK_PERM_USER_WRITE
+    filename, GNUNET_DISK_OPEN_READWRITE,
+    GNUNET_DISK_PERM_USER_READ | GNUNET_DISK_PERM_USER_WRITE
   );
 
   if (!file)
@@ -197,7 +207,7 @@ util_decrypt_file (const char *filename,
 
   struct GNUNET_DISK_MapHandle *mapping = NULL;
   void* data = GNUNET_DISK_file_map(
-      file, &mapping, GNUNET_DISK_MAP_TYPE_READWRITE, size
+    file, &mapping, GNUNET_DISK_MAP_TYPE_READWRITE, size
   );
 
   if ((!data) || (!mapping))
@@ -225,11 +235,11 @@ util_decrypt_file (const char *filename,
       memcpy(&iv, hash, sizeof(iv));
 
     result = GNUNET_CRYPTO_symmetric_decrypt(
-	location,
-	remaining >= block_size? block_size : remaining,
-	key,
-	&iv,
-	location
+      location,
+      remaining >= block_size? block_size : remaining,
+      key,
+      &iv,
+      location
     );
 
     if (result < 0)
@@ -259,42 +269,44 @@ util_decrypt_file (const char *filename,
 
 int
 util_get_dirname (const char *directory,
-		  const char *subdir,
-		  char **filename)
+                  const char *subdir,
+                  char **filename)
 {
-  GNUNET_assert((filename) &&
-  		(directory) &&
-  		(subdir));
+  GNUNET_assert(
+    (filename) &&
+    (directory) &&
+    (subdir)
+  );
 
   return GNUNET_asprintf (
-      filename,
-      "%s%c%s",
-      directory,
-      DIR_SEPARATOR,
-      subdir
+    filename,
+    "%s/%s",
+    directory,
+    subdir
   );
 }
 
 int
 util_get_filename (const char *directory,
-		   const char *subdir,
-		   const struct GNUNET_HashCode *hash,
-		   char **filename)
+                   const char *subdir,
+                   const struct GNUNET_HashCode *hash,
+                   char **filename)
 {
-  GNUNET_assert((filename) &&
+  GNUNET_assert(
+    (filename) &&
 		(directory) &&
 		(subdir) &&
-		(hash));
+		(hash)
+  );
 
   char* dirname;
   util_get_dirname(directory, subdir, &dirname);
 
   int result = GNUNET_asprintf (
-      filename,
-      "%s%c%s",
-      dirname,
-      DIR_SEPARATOR,
-      GNUNET_h2s_full(hash)
+    filename,
+    "%s/%s",
+    dirname,
+    GNUNET_h2s_full(hash)
   );
 
   GNUNET_free(dirname);
@@ -316,8 +328,8 @@ util_get_lower(const char *name)
 
 int
 util_get_context_label (enum GNUNET_CHAT_ContextType type,
-		        const struct GNUNET_HashCode *hash,
-		        char **label)
+                        const struct GNUNET_HashCode *hash,
+                        char **label)
 {
   const char *type_string = "chat";
 
@@ -336,26 +348,50 @@ util_get_context_label (enum GNUNET_CHAT_ContextType type,
   char *low = util_get_lower(GNUNET_h2s(hash));
 
   int result = GNUNET_asprintf (
-      label,
-      "%s_%s",
-      type_string,
-      low
+    label,
+    "%s_%s",
+    type_string,
+    low
   );
 
   GNUNET_free(low);
   return result;
 }
 
+enum GNUNET_CHAT_ContextType
+util_get_context_label_type (const char *label,
+			                       const struct GNUNET_HashCode *hash)
+{
+  enum GNUNET_CHAT_ContextType type = GNUNET_CHAT_CONTEXT_TYPE_UNKNOWN;
+
+  char *low = util_get_lower(GNUNET_h2s(hash));
+
+  const char *sub = strstr(label, low);
+  if ((!sub) || (sub == label) || (sub[-1] != '_'))
+    goto cleanup;
+
+  const size_t len = (size_t) (sub - label - 1);
+
+  if (0 == strncmp(label, label_prefix_of_group, len))
+    type = GNUNET_CHAT_CONTEXT_TYPE_GROUP;
+  else if (0 == strncmp(label, label_prefix_of_contact, len))
+    type = GNUNET_CHAT_CONTEXT_TYPE_CONTACT;
+
+cleanup:
+  GNUNET_free(low);
+  return type;
+}
+
 int
 util_lobby_name (const struct GNUNET_HashCode *hash,
-		 char **name)
+		             char **name)
 {
   char *low = util_get_lower(GNUNET_h2s(hash));
 
   int result = GNUNET_asprintf (
-      name,
-      "chat_lobby_%s",
-      low
+    name,
+    "chat_lobby_%s",
+    low
   );
 
   GNUNET_free(low);
@@ -381,10 +417,12 @@ util_message_kind_from_kind (enum GNUNET_MESSENGER_MessageKind kind)
       return GNUNET_CHAT_KIND_TEXT;
     case GNUNET_MESSENGER_KIND_FILE:
       return GNUNET_CHAT_KIND_FILE;
-    case GNUNET_MESSENGER_KIND_PRIVATE:
-      return GNUNET_CHAT_KIND_WHISPER;
     case GNUNET_MESSENGER_KIND_DELETE:
       return GNUNET_CHAT_KIND_DELETION;
+    case GNUNET_MESSENGER_KIND_TICKET:
+      return GNUNET_CHAT_KIND_CONTACT;
+    case GNUNET_MESSENGER_KIND_TAG:
+      return GNUNET_CHAT_KIND_TAG;
     default:
       return GNUNET_CHAT_KIND_UNKNOWN;
   }
